# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!


"""

API for the ``pyface.preference`` subpackage.

- :class:`~.PreferencePage`
- :class:`~.PreferenceDialog`
- :class:`~.PreferenceNode`

"""

from .preference_page import PreferencePage
from .preference_dialog import PreferenceDialog
from .preference_node import PreferenceNode
